@@ -1,9 +1,10 @@
+import json
+
 from StringIO import StringIO
 from ConfigParser import ConfigParser
 
 from elasticgit.tests.base import ToolBaseTest, TestPerson
 from elasticgit.commands.resync import ResyncTool, DEFAULT_SECTION
-from elasticgit.utils import fqcn
 
 
 class TestResyncTool(ToolBaseTest):
@@ -21,11 +22,12 @@ class TestResyncTool(ToolBaseTest):
             True
         self.im.refresh_indices(branch_name)
 
-    def resync(self, workspace, models_module):
+    def resync(self, workspace, model_class, mapping_file=None):
         tool = ResyncTool()
         tool.stdout = StringIO()
-        tool.run(None, models_module,
-                 workspace.index_prefix, workspace.working_dir)
+        tool.run(None, model_class,
+                 workspace.index_prefix, workspace.working_dir,
+                 mapping_file)
         return tool.stdout.getvalue()
 
     def test_resync_empty_index(self):
@@ -41,7 +43,7 @@ class TestResyncTool(ToolBaseTest):
         self.recreate_index(branch_name)
         self.assertEqual(self.workspace.S(TestPerson).count(), 0)
 
-        output = self.resync(self.workspace, fqcn(TestPerson))
+        output = self.resync(self.workspace, TestPerson)
         self.assertEqual(
             'elasticgit.tests.base.TestPerson: 1 updated, 0 removed.\n',
             output)
@@ -61,7 +63,7 @@ class TestResyncTool(ToolBaseTest):
 
         self.workspace.refresh_index()
         self.assertEqual(self.workspace.S(TestPerson).count(), 1)
-        output = self.resync(self.workspace, fqcn(TestPerson))
+        output = self.resync(self.workspace, TestPerson)
         self.assertEqual(
             'elasticgit.tests.base.TestPerson: 0 updated, 1 removed.\n',
             output)
@@ -92,17 +94,40 @@ class TestResyncTool(ToolBaseTest):
         self.workspace.refresh_index()
 
         self.assertEqual(self.workspace.S(TestPerson).count(), 1)
-        output = self.resync(self.workspace, fqcn(TestPerson))
+        output = self.resync(self.workspace, TestPerson)
         self.assertEqual(
             'elasticgit.tests.base.TestPerson: 3 updated, 0 removed.\n',
             output)
         self.workspace.refresh_index()
         self.assertEqual(self.workspace.S(TestPerson).count(), 3)
 
+    def test_mapping(self):
+        mapping = {
+            'properties': {
+                'uuid': {
+                    'type': 'string',
+                    'index': 'not_analyzed',
+                },
+                'name': {
+                    'type': 'string',
+                    'index': 'not_analyzed',
+                },
+                'age': {
+                    'type': 'integer',
+                },
+            }
+        }
+        mapping_file = StringIO()
+        json.dump(mapping, fp=mapping_file)
+        mapping_file.seek(0)
+        self.resync(self.workspace, TestPerson, mapping_file=mapping_file)
+        self.assertEqual(
+            self.workspace.get_mapping(TestPerson), mapping)
+
 
 class TestResyncToolWithConfigFile(TestResyncTool):
 
-    def resync(self, workspace, models_module):
+    def resync(self, workspace, models_module, mapping_file=None):
         parser = ConfigParser()
         parser.add_section(DEFAULT_SECTION)
         parser.set(DEFAULT_SECTION, 'git.path',
@@ -115,5 +140,5 @@ class TestResyncToolWithConfigFile(TestResyncTool):
 
         tool = ResyncTool()
         tool.stdout = StringIO()
-        tool.run(sio, models_module, None, None)
+        tool.run(sio, models_module, None, None, mapping_file)
         return tool.stdout.getvalue()
